// eslint-disable-next-line import/no-unresolved
import "./style.css";
